@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2009-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2009-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 //
 // C++ Implementation: valawriter
@@ -207,7 +202,7 @@ void ValaWriter::writeClass(UMLClassifier *c)
     //Start generating the code!!
     /////////////////////////////
 
-    //try to find a heading file (license, coments, etc)
+    //try to find a heading file (license, comments, etc)
     QString str;
     str = getHeadingFile(QLatin1String(".vala"));
     if (!str.isEmpty()) {
@@ -228,7 +223,7 @@ void ValaWriter::writeClass(UMLClassifier *c)
     //write includes and namespace
     UMLPackage *container = c->umlPackage();
     if (container == logicalView) {
-        container = NULL;
+        container = 0;
     }
 
     UMLPackageList includes;
@@ -237,7 +232,7 @@ void ValaWriter::writeClass(UMLClassifier *c)
     //m_seenIncludes.append(logicalView);
     if (includes.count()) {
         foreach (UMLPackage* p, includes) {
-            UMLClassifier *cl = dynamic_cast<UMLClassifier*>(p);
+            UMLClassifier *cl = p->asUMLClassifier();
             if (cl) {
                 p = cl->umlPackage();
             }
@@ -258,7 +253,7 @@ void ValaWriter::writeClass(UMLClassifier *c)
         m_seenIncludes.append(container);
     }
 
-    //Write class Documentation if there is somthing or if force option
+    //Write class Documentation if there is something or if force option
     if (forceDoc() || !c->doc().isEmpty()) {
         cs << m_container_indent << "/**" << m_endl;
         if (c->doc().isEmpty()) {
@@ -720,11 +715,11 @@ void ValaWriter::writeAssociatedAttributes(UMLAssociationList &associated, UMLCl
         }
 
         UMLObject *o = a->getObject(Uml::RoleType::B);
-        if (o == NULL) {
+        if (o == 0) {
             uError() << "composition role B object is NULL";
             continue;
         }
-        // Take name and documentaton from Role, take type name from the referenced object
+        // Take name and documentation from Role, take type name from the referenced object
         QString roleName = cleanName(a->getRoleName(Uml::RoleType::B));
         QString typeName = cleanName(o->name());
         if (roleName.isEmpty()) {
@@ -823,13 +818,14 @@ void ValaWriter::writeAttribute(const QString& doc,
  */
 QString ValaWriter::makeLocalTypeName(UMLClassifierListItem *cl)
 {
-    UMLPackage *p = cl->getType()->umlPackage();
-    if (m_seenIncludes.indexOf(p) != -1) {
-        return cl->getType()->name();
-    }
-    else {
-        return cl->getTypeName();
+    UMLClassifier *c = cl->getType();
+    if (c) {
+        UMLPackage *p = c->umlPackage();
+        if (m_seenIncludes.indexOf(p) != -1) {
+            return c->name();
+        }
     }
+    return cl->getTypeName();
 }
 
 /**
