@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2008-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2008-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #include "docbookgeneratorjob.h"
 
@@ -44,7 +39,7 @@
 extern int xmlLoadExtDtdDefaultValue;
 
 #define MAX_PATHS 64
-xmlExternalEntityLoader defaultEntityLoader = NULL;
+static xmlExternalEntityLoader defaultEntityLoader = NULL;
 static xmlChar *paths[MAX_PATHS + 1];
 static int nbpaths = 0;
 static QHash<QString,QString> replaceURLList;
@@ -58,7 +53,7 @@ static xmlParserInputPtr xsltprocExternalEntityLoader(const char *_URL, const ch
     xmlParserInputPtr ret;
     warningSAXFunc warning = NULL;
 
-    // use local available dtd versions instead of fetching it everytime from the internet
+    // use local available dtd versions instead of fetching it every time from the internet
     QString url = QLatin1String(_URL);
     QHash<QString, QString>::const_iterator i;
     for(i = replaceURLList.constBegin(); i != replaceURLList.constEnd(); i++)
@@ -69,19 +64,8 @@ static xmlParserInputPtr xsltprocExternalEntityLoader(const char *_URL, const ch
             qDebug() << "converted" << _URL << "to" << url;
         }
     }
-    char URL[1024];
-    strcpy(URL,url.toLatin1().constData());
 
-    const char *lastsegment = URL;
-    const char *iter = URL;
-
-    if (nbpaths > 0) {
-        while (*iter != 0) {
-            if (*iter == '/')
-            lastsegment = iter + 1;
-            iter++;
-        }
-    }
+    QByteArray URL = url.toLatin1();
 
     if ((ctxt != NULL) && (ctxt->sax != NULL)) {
         warning = ctxt->sax->warning;
@@ -89,7 +73,7 @@ static xmlParserInputPtr xsltprocExternalEntityLoader(const char *_URL, const ch
     }
 
     if (defaultEntityLoader != NULL) {
-        ret = defaultEntityLoader(URL, ID, ctxt);
+        ret = defaultEntityLoader(URL.constData(), ID, ctxt);
         if (ret != NULL) {
             if (warning != NULL)
                 ctxt->sax->warning = warning;
@@ -97,6 +81,10 @@ static xmlParserInputPtr xsltprocExternalEntityLoader(const char *_URL, const ch
             return(ret);
         }
     }
+
+    int j = URL.lastIndexOf("/");
+    const char *lastsegment = j > -1 ? URL.constData()+j+1 : URL.constData();
+
     for (int i = 0;i < nbpaths;i++) {
         xmlChar *newURL;
 
@@ -117,8 +105,8 @@ static xmlParserInputPtr xsltprocExternalEntityLoader(const char *_URL, const ch
     }
     if (warning != NULL) {
         ctxt->sax->warning = warning;
-        if (URL != NULL)
-            warning(ctxt, "failed to load external entity \"%s\"\n", URL);
+        if (_URL != NULL)
+            warning(ctxt, "failed to load external entity \"%s\"\n", _URL);
         else if (ID != NULL)
             warning(ctxt, "failed to load external entity \"%s\"\n", ID);
     }
